@@ -197,8 +197,6 @@ test_that("running sum",{#FOLDUP
 			}
 		}
 	}
-
-
 })#UNFOLD
 test_that("constant input",{#FOLDUP
 	x <- rep(1,8)
@@ -485,5 +483,128 @@ test_that("running adjustments",{#FOLDUP
 	#expect_error(running_tstat(x,window=20L,restart_period='FOO'))
 })#UNFOLD
 
+context("running x y code")
+test_that("runs without error",{#FOLDUP
+	skip_on_cran()
+
+	set.char.seed("c13a49ac-14e9-462b-b81e-d3a5fc3be491")
+	nel <- 20
+	xna <- rnorm(nel)
+	xna[xna < -0.5] <- NA
+	xall <- list(rnorm(nel),
+							 xna,
+							 as.integer(rnorm(nel,sd=100)))
+
+	wna <- runif(nel,min=1,max=3)
+	wna[wna < 1.5] <- NA
+	wall <- list(rep(1.0,nel),
+							 runif(nel,min=0.9,max=3.5),
+							 wna,
+							 as.integer(ceiling(runif(nel,min=2,max=100))),
+							 as.logical(ceiling(pmax(0,rnorm(nel)))),
+							 NULL)
+
+	for (x_thingy in xall) {
+		y_thingy <- x_thingy + 1
+		for (wts in wall) {
+			for (window in c(5,21,Inf,NULL)) {
+				for (na_rm in c(FALSE,TRUE)) {
+					for (rp in c(1L,40L)) {
+						expect_error(running_correlation(x_thingy,y_thingy,wts=wts,window=window,restart_period=rp,na_rm=na_rm),NA)
+						expect_error(running_covariance(x_thingy,y_thingy,wts=wts,window=window,restart_period=rp,na_rm=na_rm),NA)
+						expect_error(running_covariance_3(x_thingy,y_thingy,wts=wts,window=window,restart_period=rp,na_rm=na_rm),NA)
+						expect_error(running_regression_slope(x_thingy,y_thingy,wts=wts,window=window,restart_period=rp,na_rm=na_rm),NA)
+						expect_error(running_regression_intercept(x_thingy,y_thingy,wts=wts,window=window,restart_period=rp,na_rm=na_rm),NA)
+						expect_error(running_regression_fit(x_thingy,y_thingy,wts=wts,window=window,restart_period=rp,na_rm=na_rm),NA)
+						expect_error(running_regression_diagnostics(x_thingy,y_thingy,wts=wts,window=window,restart_period=rp,na_rm=na_rm),NA)
+					}
+				}
+			}
+		}
+	}
+})#UNFOLD
+test_that("covariance correctness",{#FOLDUP
+	skip_on_cran()
+
+	set.char.seed("b81052f6-d7a5-4f3f-95cf-bc8d0030fcf8")
+	window <- 30
+	maxplus <- 50
+	nel <- window + maxplus
+	xvec <- rnorm(nel)
+	beta_0 <- 0.33
+	beta_1 <- 5
+	sigma <- 0.5
+	yvec <- beta_0 + beta_1 * xvec + rnorm(length(xvec),sd=sigma)
+	expect_error(rho <- running_correlation(xvec,yvec,window=window),NA)
+	expect_equal(rho[window], cor(xvec[1:window],yvec[1:window]), tolerance=1e-12)
+	expect_equal(rho[1+window], cor(xvec[2:(1+window)],yvec[2:(1+window)]), tolerance=1e-12)
+
+	expect_error(rho <- running_covariance(xvec,yvec,window=window,used_df=1),NA)
+	expect_equal(rho[window], cov(xvec[1:window],yvec[1:window]), tolerance=1e-12)
+	expect_equal(rho[1+window], cov(xvec[2:(1+window)],yvec[2:(1+window)]), tolerance=1e-12)
+
+	expect_error(beta_1 <- running_regression_slope(xvec,yvec,window=window),NA)
+	expect_error(beta_0 <- running_regression_intercept(xvec,yvec,window=window),NA)
+	mod0 <- lm(yvec[1:window] ~ xvec[1:window])
+	ses <- sqrt(diag(vcov(mod0)))
+
+	expect_equal(beta_0[window], coefficients(mod0)[[1]], tolerance=1e-12)
+	expect_equal(beta_1[window], coefficients(mod0)[[2]], tolerance=1e-12)
+	expect_error(beta_ff <- running_regression_fit(xvec,yvec,window=window),NA)
+	expect_equal(beta_ff[,1,drop=FALSE], beta_0, tolerance=1e-12)
+	expect_equal(beta_ff[,2,drop=FALSE], beta_1, tolerance=1e-12)
+	expect_error(beta_dd <- running_regression_diagnostics(xvec,yvec,window=window),NA)
+	expect_equal(beta_dd[,1,drop=FALSE], beta_0, tolerance=1e-12)
+	expect_equal(beta_dd[,2,drop=FALSE], beta_1, tolerance=1e-12)
+	# also compare against diag(vcov(mod0))
+	expect_equal(beta_dd[window,3], summary(mod0)$sigma, tolerance=1e-12)
+	expect_equal(beta_dd[window,4], as.numeric(ses[1]), tolerance=1e-12)
+	expect_equal(beta_dd[window,5], as.numeric(ses[2]), tolerance=1e-12)
+
+	# and a little bit forward
+	for (offs in c(5, maxplus - 1)) {
+		mod1 <- lm(yvec[offs + (1:window)] ~ xvec[offs + (1:window)])
+		ses <- sqrt(diag(vcov(mod1)))
+		expect_equal(beta_0[offs+window], coefficients(mod1)[[1]], tolerance=1e-12)
+		expect_equal(beta_1[offs+window], coefficients(mod1)[[2]], tolerance=1e-12)
+		expect_equal(beta_dd[offs+window,3], summary(mod1)$sigma, tolerance=1e-12)
+		expect_equal(beta_dd[offs+window,4], as.numeric(ses[1]), tolerance=1e-12)
+		expect_equal(beta_dd[offs+window,5], as.numeric(ses[2]), tolerance=1e-12)
+	}
+})#UNFOLD
+test_that("covariance weighting correctness",{#FOLDUP
+	skip_on_cran()
+
+	set.char.seed("f3d1652c-2d83-4670-998b-f96d18d18374")
+	window <- 50
+	nel <- window
+	xvec <- rnorm(nel)
+	beta_0 <- 0.33
+	beta_1 <- 5
+	sigma <- 0.5
+	yvec <- beta_0 + beta_1 * xvec + rnorm(length(xvec),sd=sigma)
+	wts <- sample(c(1,2,3),nel,replace=TRUE)
+	expect_error(rho <- running_correlation(xvec,yvec,wts=wts,window=window),NA)
+	bigx <- rep(xvec,wts)
+	bigy <- rep(yvec,wts)
+	expect_error(rho2 <- running_correlation(bigx,bigy,window=length(bigx)),NA)
+	expect_equal(rho[window],rho2[length(rho2)], tolerance=1e-12)
+
+	expect_error(rho <- running_covariance(xvec,yvec,wts=wts,window=window,normalize_wts=FALSE,used_df=1),NA)
+	expect_error(rho2 <- running_covariance(bigx,bigy,window=length(bigx),used_df=1),NA)
+	expect_equal(rho[window],rho2[length(rho2)], tolerance=1e-12)
+
+	expect_error(beta_0 <- running_regression_intercept(xvec,yvec,wts=wts,window=window),NA)
+	expect_error(beta_1 <- running_regression_slope(xvec,yvec,wts=wts,window=window),NA)
+	expect_error(beta_02 <- running_regression_intercept(bigx,bigy,window=length(bigx)),NA)
+	expect_error(beta_12 <- running_regression_slope(bigx,bigy,window=length(bigx)),NA)
+	expect_equal(beta_0[window],beta_02[length(bigx)], tolerance=1e-12)
+	expect_equal(beta_1[window],beta_12[length(bigx)], tolerance=1e-12)
+
+	expect_error(beta_dd <- running_regression_diagnostics(xvec,yvec,wts=wts,window=window,normalize_wts=FALSE),NA)
+	expect_error(beta_dd2 <- running_regression_diagnostics(bigx,bigy,window=length(bigx)),NA)
+	expect_equal(beta_dd[window,,drop=TRUE],beta_dd2[length(bigx),,drop=TRUE], tolerance=1e-12)
+})#UNFOLD
+
 #for vim modeline: (do not edit)
 # vim:ts=2:sw=2:tw=79:fdm=marker:fmr=FOLDUP,UNFOLD:cms=#%s:syn=r:ft=r:ai:si:cin:nu:fo=croql:cino=p0t0c5(0:
